module.exports = {
	name: 'pagination',
	slots: [
		{
			name: 'previous',
			description: 'Slot for previous button content',
			type: []
		},
		{
			name: 'next',
			description: 'Slot for next button content',
			type: []
		}
	],
	events: [
		{
			name: 'update:modelValue',
			description: 'Event emitted for setting the modelValue',
			type: []
		}
	],
	props: [
		{
			name: 'color',
			description: 'The color variant of the pagination',
			type: [
				'light',
				'dark'
			],
			default: 'light'
		},
		{
			name: 'itemsPerPage',
			description: 'The number of items per page to be displayed',
			type: [
				'Number'
			],
			default: '20'
		},
		{
			name: 'itemsTotal',
			description: 'The total number of items',
			type: [
				'Number'
			],
			default: '0'
		},
		{
			name: 'limit',
			description: 'The maximum number of pagination buttons to show on each breakpoint',
			type: [
				'Number',
				'Object'
			],
			default: '{\n    xs: 3,\n    sm: 5\n}'
		},
		{
			name: 'quickLink',
			description: 'Display the quick link buttons',
			type: [
				'Boolean'
			],
			default: 'false'
		},
		{
			name: 'modelValue',
			description: 'Used to determine the current page',
			type: [
				'Number'
			],
			default: '1'
		},
		{
			name: 'size',
			description: 'The size variant of the pagination',
			type: [
				'sm',
				'md',
				'lg'
			],
			default: 'md'
		}
	],
	styles: [
		{
			name: 'border-width',
			description: 'The border width of the pagination component',
			default: 'var(--border-width)'
		},
		{
			name: 'margin',
			description: 'The margin of the pagination component items',
			default: 'spacing(\'1/4\')'
		},
		{
			name: 'opacity-disabled',
			description: 'The opacity of the pagination component when disabled',
			default: '0.85'
		},
		{
			name: 'border-radius',
			description: 'The border radius of the pagination component',
			type: 'size',
			default: 'border-radius()'
		},
		{
			name: 'font-size',
			description: 'The font size of the pagination component',
			type: 'size',
			default: 'font-size()'
		},
		{
			name: 'padding',
			description: 'The padding of the pagination component',
			type: 'size',
			default: 'spacing(\'1/2\')'
		},
		{
			name: 'min-width',
			description: 'The minimum width of the pagination component items',
			type: 'size',
			default: '40px'
		},
		{
			name: 'background',
			description: 'The background of the pagination component item',
			type: 'color',
			variants: {
				light: 'color(\'light\')',
				dark: 'color(\'dark\')'
			}
		},
		{
			name: 'background-hover',
			description: 'The background of the pagination component item when hovered or focused',
			type: 'color',
			variants: {
				light: 'color(\'light-55\')',
				dark: 'color(\'dark-45\')'
			}
		},
		{
			name: 'background-active',
			description: 'The background of the pagination component item when active',
			type: 'color',
			variants: {
				light: 'color(\'primary\')',
				dark: 'color(\'primary\')'
			}
		},
		{
			name: 'border-color',
			description: 'The border color of the pagination component item',
			type: 'color',
			variants: {
				light: 'color(\'light-55\')',
				dark: 'color(\'dark-45\')'
			}
		},
		{
			name: 'border-color-active',
			description: 'The border color of the pagination component item when active',
			type: 'color',
			variants: {
				light: 'color(\'primary-55\')',
				dark: 'color(\'primary-55\')'
			}
		},
		{
			name: 'color',
			description: 'The border color of the pagination component item when active',
			type: 'color',
			variants: {
				light: 'contrast-color($color-light)',
				dark: 'contrast-color($color-dark)'
			}
		},
		{
			name: 'color-active',
			description: 'The border color of the pagination component item when active',
			type: 'color',
			variants: {
				light: 'contrast-color($color-primary)',
				dark: 'contrast-color($color-primary)'
			}
		}
	]
};
