module.exports = {
	name: 'popover',
	slots: [
		{
			name: 'default',
			description: 'Slot for tooltip trigger',
			type: []
		},
		{
			name: 'header',
			description: 'Slot for tooltip header content',
			type: []
		},
		{
			name: 'body',
			description: 'Slot for tooltip body content',
			type: []
		},
		{
			name: 'footer',
			description: 'Slot for tooltip footer content',
			type: []
		}
	],
	events: [
		{
			name: 'update:modelValue',
			description: 'Event emitted for setting the modelValue',
			type: []
		}
	],
	props: [
		{
			name: 'color',
			description: 'The color variant of the popover',
			type: [
				'light',
				'dark'
			],
			default: 'light'
		},
		{
			name: 'disabled',
			description: 'The disabled state of the popover',
			type: [
				'Boolean'
			],
			default: 'false'
		},
		{
			name: 'modelValue',
			description: 'Used to manually control the visibility of the popover',
			type: [
				'Boolean'
			],
			default: 'false'
		},
		{
			name: 'arrow',
			description: 'Displays an arrow on the popover pointing to the trigger element',
			type: [
				'Boolean'
			],
			default: 'true'
		},
		{
			name: 'placement',
			description: 'The placement of the popover',
			type: [
				'top',
				'top-start',
				'top-end',
				'bottom',
				'bottom-start',
				'bottom-end',
				'left',
				'left-start',
				'left-end',
				'right',
				'right-start',
				'right-end'
			],
			default: 'false'
		},
		{
			name: 'trigger',
			description: 'The events used to trigger the popover',
			type: [
				'hover',
				'focus',
				'click',
				'manual'
			],
			default: '[click]'
		},
		{
			name: 'offset',
			description: 'The offset of the popover relative to the trigger element',
			type: [
				'Number'
			],
			default: '6'
		},
		{
			name: 'popperOptions',
			description: 'Used to override the popper.js options used for creating the popover',
			type: [
				'Object'
			],
			default: '{}'
		},
		{
			name: 'size',
			description: 'The size variant of the popover',
			type: [
				'sm',
				'md',
				'lg'
			],
			default: 'md'
		}
	],
	styles: [
		{
			name: 'font-weight',
			description: 'The font weight of the popover component',
			default: 'font-weight(\'normal\')'
		},
		{
			name: 'line-height',
			description: 'The line height of the popover component',
			default: 'var(--line-height)'
		},
		{
			name: 'border-width',
			description: 'The border width of the popover component',
			default: 'var(--border-width)'
		},
		{
			name: 'margin',
			description: 'The margin of the popover component',
			default: 'spacing(\'1/2\')'
		},
		{
			name: 'z-index',
			description: 'The z-index of the popover component',
			default: '2000'
		},
		{
			name: 'width',
			description: 'The width of the popover component',
			default: '280px'
		},
		{
			name: 'max-width',
			description: 'The maximum width of the popover component',
			default: '90vw'
		},
		{
			name: 'border-radius',
			description: 'The border radius of the popover component',
			type: 'size',
			default: 'border-radius()'
		},
		{
			name: 'font-size',
			description: 'The font size of the popover component',
			type: 'size',
			default: 'font-size()'
		},
		{
			name: 'padding',
			description: 'The padding of the popover component items',
			type: 'size',
			default: 'spacing()',
			variants: {
				sm: [
					'var(--popover-padding) * 3 / 4',
					'var(--popover-padding)'
				],
				md: [
					'var(--popover-padding) * 3 / 4',
					'var(--popover-padding)'
				],
				lg: [
					'var(--popover-padding) * 3 / 4',
					'var(--popover-padding)'
				]
			}
		},
		{
			name: 'color',
			description: 'The color of the popover component item',
			type: 'color',
			variants: {
				light: 'contrast-color($color-white)',
				dark: 'contrast-color($color-dark)'
			}
		},
		{
			name: 'background',
			description: 'The background of the popover component',
			type: 'color',
			variants: {
				light: 'color(\'white\')',
				dark: 'color(\'dark\')'
			}
		},
		{
			name: 'border-color',
			description: 'The border-color of the popover component',
			type: 'color',
			variants: {
				light: 'color(\'light\')',
				dark: 'color(\'dark-60\')'
			}
		},
		{
			name: 'header-background',
			description: 'The background of the popover component header',
			type: 'color',
			variants: {
				light: 'color(\'gray-05\')',
				dark: 'color(\'dark-55\')'
			}
		},
		{
			name: 'footer-background',
			description: 'The background of the popover component footer',
			type: 'color',
			variants: {
				light: 'color(\'gray-05\')',
				dark: 'color(\'dark-55\')'
			}
		}
	]
};
