module.exports = {
	name: 'sidebar',
	slots: [
		{
			name: 'default',
			description: 'Slot for default sidebar content',
			type: []
		}
	],
	events: [
		{
			name: 'update:modelValue',
			description: 'Event emitted for setting the modelValue',
			type: []
		}
	],
	props: [
		{
			name: 'collapseOnItemClick',
			description: 'Determines if the sidebar should close when clicking a sidebar item',
			type: [
				'Boolean'
			],
			default: 'true'
		},
		{
			name: 'collapseOnClickOutside',
			description: 'Determines if the sidebar should close when clicking outside, on the overlay',
			type: [
				'Boolean'
			],
			default: 'true'
		},
		{
			name: 'collapsePosition',
			description: 'The collapse position of the sidebar',
			type: [
				'fixed',
				'absolute',
				'relative'
			],
			default: 'absolute'
		},
		{
			name: 'color',
			description: 'The color variant of the sidebar',
			type: [
				'light',
				'dark'
			],
			default: 'light'
		},
		{
			name: 'placement',
			description: 'The placement of the sidebar',
			type: [
				'left',
				'right'
			],
			default: 'left'
		},
		{
			name: 'size',
			description: 'The size variant of the navbar',
			type: [
				'sm',
				'md',
				'lg'
			],
			default: 'md'
		}
	],
	styles: [
		{
			name: 'border-radius',
			description: 'The border radius of the sidebar component',
			type: 'size',
			default: 'border-radius()'
		},
		{
			name: 'font-size',
			description: 'The font size of the sidebar component',
			type: 'size',
			default: 'font-size()'
		},
		{
			name: 'padding',
			description: 'The padding of the sidebar component',
			type: 'size',
			default: 'spacing()'
		},
		{
			name: 'item-padding',
			description: 'The padding of the sidebar component item',
			type: 'size',
			default: 'spacing()',
			variants: {
				sm: 'calc(var(--sidebar-item-padding) * #{size-multiplier(\'sm\')} / 2) calc(var(--sidebar-item-padding) * #{size-multiplier(\'sm\')})',
				md: 'calc(var(--sidebar-item-padding) * #{size-multiplier(\'md\')} / 2) calc(var(--sidebar-item-padding) * #{size-multiplier(\'md\')})',
				lg: 'calc(var(--sidebar-item-padding) * #{size-multiplier(\'lg\')} / 2) calc(var(--sidebar-item-padding) * #{size-multiplier(\'lg\')})'
			}
		},
		{
			name: 'width',
			description: 'The width of the sidebar component',
			type: 'size',
			default: '14rem'
		},
		{
			name: 'overlay-background',
			description: 'The background of the sidebar component overlay',
			default: 'rgba(0, 0, 0, 0.5)'
		},
		{
			name: 'z-index',
			description: 'The z-index of the sidebar component',
			default: 'z-index(\'fixed\')'
		},
		{
			name: 'color',
			description: 'The color of the sidebar component',
			type: 'color',
			variants: {
				light: 'contrast-color($color-light)',
				dark: 'contrast-color($color-dark)'
			}
		},
		{
			name: 'background',
			description: 'The background of the sidebar component',
			type: 'color',
			variants: {
				light: 'color(\'light\')',
				dark: 'color(\'dark\')'
			}
		},
		{
			name: 'item-color',
			description: 'The color of the sidebar component item',
			type: 'color',
			variants: {
				light: 'contrast-color($color-light)',
				dark: 'contrast-color($color-dark)'
			}
		},
		{
			name: 'item-color-hover',
			description: 'The color of the sidebar component item when hovered',
			type: 'color',
			variants: {
				light: 'contrast-color($color-light)',
				dark: 'contrast-color($color-dark)'
			}
		},
		{
			name: 'item-background',
			description: 'The background of the sidebar component item',
			type: 'color',
			variants: {
				light: 'color(\'light\')',
				dark: 'color(\'dark\')'
			}
		},
		{
			name: 'item-background-hover',
			description: 'The background of the sidebar component item when hovered or focused',
			type: 'color',
			variants: {
				light: 'color(\'light-55\')',
				dark: 'color(\'dark-45\')'
			}
		}
	]
};
