module.exports = {
	name: 'tabs',
	slots: [
		{
			name: 'default',
			description: 'Slot for default tabs content',
			type: []
		}
	],
	events: [
		{
			name: 'update:modelValue',
			description: 'Event emitted for setting the modelValue',
			type: []
		}
	],
	props: [
		{
			name: 'color',
			description: 'The color variant of the header',
			type: [
				'primary',
				'light',
				'dark'
			],
			default: 'light'
		},
		{
			name: 'modelValue',
			description: 'Used to set the currently active tab',
			type: [
				'String'
			],
			default: '{"type":"","default":""}'
		},
		{
			name: 'size',
			description: 'The size variant of the tabs',
			type: [
				'sm',
				'md',
				'lg'
			],
			default: 'md'
		},
		{
			name: 'stretch',
			description: 'Display the tabs header as full width',
			type: [
				'Boolean'
			],
			default: 'false'
		}
	],
	styles: [
		{
			name: 'border-width',
			description: 'The border width of the tabs component',
			default: 'var(--border-width)'
		},
		{
			name: 'header-border-bottom-width',
			description: 'The bottom border width of the tabs component header',
			default: '2px'
		},
		{
			name: 'header-margin-bottom',
			description: 'The bottom margin of the tabs component header',
			default: '-1px'
		},
		{
			name: 'font-size',
			description: 'The font size of the tabs component',
			type: 'size',
			default: 'font-size()'
		},
		{
			name: 'border-radius',
			description: 'The border radius of the tabs component',
			type: 'size',
			default: 'border-radius()'
		},
		{
			name: 'padding',
			description: 'The padding of the tabs component',
			type: 'size',
			default: 'spacing()'
		},
		{
			name: 'header-padding',
			description: 'The padding of the tabs component header',
			type: 'size',
			default: 'spacing()'
		},
		{
			name: 'color',
			description: 'The color of the tabs component item',
			type: 'color',
			variants: {
				light: 'contrast-color($color-white)',
				dark: 'contrast-color($color-dark)'
			}
		},
		{
			name: 'background',
			description: 'The background of the tabs component',
			type: 'color',
			variants: {
				light: 'color(\'white\')',
				dark: 'color(\'dark\')'
			}
		},
		{
			name: 'border-color',
			description: 'The border-color of the tabs component',
			type: 'color',
			variants: {
				light: 'color(\'light\')',
				dark: 'color(\'dark-60\')'
			}
		},
		{
			name: 'header-background',
			description: 'The background of the tabs component header',
			type: 'color',
			variants: {
				light: 'color(\'white\')',
				dark: 'color(\'dark\')'
			}
		},
		{
			name: 'header-background-active',
			description: 'The background of the tabs component header when active',
			type: 'color',
			variants: {
				light: 'color(\'white\')',
				dark: 'color(\'dark\')'
			}
		},
		{
			name: 'header-background-hover',
			description: 'The background of the tabs component header when hovered or focused',
			type: 'color',
			variants: {
				light: 'color(\'gray-05\')',
				dark: 'color(\'dark-45\')'
			}
		},
		{
			name: 'header-border-color',
			description: 'The border color of the tabs component header',
			type: 'color',
			variants: {
				light: 'transparent',
				dark: 'transparent'
			}
		},
		{
			name: 'header-border-color-active',
			description: 'The border color of the tabs component header when active',
			type: 'color',
			variants: {
				light: 'color(\'primary\')',
				dark: 'color(\'primary\')'
			}
		},
		{
			name: 'header-color-active',
			description: 'The color of the tabs component header when active',
			type: 'color',
			variants: {
				light: 'contrast-color($color-white)',
				dark: 'contrast-color($color-dark)'
			}
		}
	]
};
